Function envmnt::get_i16 [−][src]
pub fn get_i16<K: AsRef<OsStr>>(key: K, default_value: i16) -> i16
Returns the environment variable value or a default value in case the variable is not defined or cannot be parsed.
Arguments
key- The environment variable namedefault_value- Returned if the variable does not exist or cannot be parsed