Struct envmnt::types::ListOptions [−][src]
Get/Set list options
Fields
separator: Option<String>The separator used to merge/split the values
ignore_empty: boolif true, empty list will not be set and empty string will be considered as a list with a single empty value
Implementations
Creates and returns a new instance.